@@ -23,10 +23,19 @@
 #ifndef MAIN_H
 #define MAIN_H
 
-#include <gtk/gtkwindow.h>
+#include <brasero/brasero-drive.h>
+#include "goo-window.h"
 
-extern GtkWindow *main_window;
-extern int AutoPlay;
-extern int HideShow;
+extern GtkWidget *main_window;
+extern GList     *window_list;
+extern int        AutoPlay;
+extern int        HideShow;
+
+GtkWidget *     main_get_window_from_device (const char *device);
+BraseroDrive *  main_get_most_likely_drive  (void);
+BraseroDrive *  main_get_drive_for_device   (const char *device);
+void            system_notify               (GooWindow  *window,
+	       			             const char *title,
+	       			             const char *msg);
 
 #endif /* MAIN_H */
